@@ -24,3 +24,6 @@
 
 /* Define to 'unsigned' if <sys/types.h> doesn't define. */
 #undef loff_t
+
+/* Define iff <linux/ext2_fs.h> has a struct ext2_dir_entry_2. */
+#undef HAVE_EXT2_DIR_ENTRY_2
