@@ -18,13 +18,31 @@
 */
 
 #include "config.h"
+#include <sys/types.h>
+
+#if HAVE_LSEEK64
+#define __USE_LARGEFILE64
+#include <unistd.h>
+/* I'm not sure if this is the right thing to do, or if it even works  */
+inline loff_t ext2_llseek (unsigned int fd, loff_t offset, unsigned int whence)
+{
+	loff_t ret = lseek64(fd, offset, whence);
+	return ret != offset;
+}
+
+#elif HAVE_LLSEEK
+inline loff_t ext2_llseek (unsigned int fd, loff_t offset, unsigned int whence)
+{
+	return llseek(fd, offset, whence);
+}
+#elif HAVE_LINUX_UNISTD_H
+
+static const char _llseek_c[] = "$Id: llseek.c,v 1.6 2000/10/10 18:34:33 adilger Exp $";
 
 #include <errno.h>
 #include <sys/types.h>
 #include <unistd.h>
 
-#if !HAVE_LLSEEK && HAVE_LINUX_UNISTD_H
-
 #include <linux/unistd.h>
 
 #if defined(__i386__)
@@ -35,7 +53,7 @@
 
 static _syscall5(int,_llseek,unsigned int,fd,unsigned long,offset_high,unsigned long,offset_low,loff_t *,result,unsigned int,origin);
 
-loff_t llseek (unsigned int fd, loff_t offset, unsigned int whence)
+loff_t ext2_llseek (unsigned int fd, loff_t offset, unsigned int whence)
 {
 	loff_t result;
 	int retval;
@@ -46,10 +64,10 @@ loff_t llseek (unsigned int fd, loff_t offset, unsigned int whence)
 			 &result,
 			 whence);
 
-	return (retval==-1 ? (loff_t) retval : result);
+	return (retval == -1 ? (loff_t) retval : result);
 }
 
-#endif
+#endif /* __i386__ */
 
 
-#endif
+#endif /* !HAVE_LLSEEK && HAVE_LINUX_UNISTD_H */
